# rpy2-r6
![Python package](https://github.com/rpy2/rpy2-R6/workflows/Python%20package/badge.svg)

Extension package for [`rpy2`](https://github.com/rpy2/rpy2) to faciliate
the handling of R6 objects ([R6 is an OOP system for R](https://r6.r-lib.org/)).

(an earlier proof-of-concept was in @matthewwardrop's PR on bitbucket - https://bitbucket.org/rpy2/rpy2/pull-requests/73 - and this is a proposed-yet-currently incomplete evolution of it)

An HTML build of the documention in is available from the rpy2 project pages: https://rpy2.github.io/r6_doc.html
